@@ -53,7 +53,7 @@ OS_ALIASES = {
 #   then A can run C) unless the entry in the list starts with '!' (e.g.
 #   {'A': ['B', '!C'], 'B': ['C']} means that A cannot run C even if B can)
 OS_COMPATIBILITY = {
-    "centos8": ["centos7"],
+    "centos8": [],
     "centos7": ["slc6", "!slc5"],
     "slc6": ["slc5"],
     "slc5": ["slc4"],
@@ -259,9 +259,9 @@ def compatible_platforms(required):
     List the dirac platforms that match the required platform.
 
     >>> compatible_platforms('skylake-centos7')
-    ['cannonlake-any', 'skylake_avx512-any', 'x86_64_v4-any', 'skylake-any', 'cannonlake-centos8', 'skylake_avx512-centos8', 'x86_64_v4-centos8', 'skylake-centos8', 'cannonlake-centos7', 'skylake_avx512-centos7', 'x86_64_v4-centos7', 'skylake-centos7']
+    ['cannonlake-any', 'skylake_avx512-any', 'x86_64_v4-any', 'skylake-any', 'cannonlake-centos7', 'skylake_avx512-centos7', 'x86_64_v4-centos7', 'skylake-centos7']
     >>> compatible_platforms('skylake-slc6')
-    ['cannonlake-any', 'skylake_avx512-any', 'x86_64_v4-any', 'skylake-any', 'cannonlake-centos8', 'skylake_avx512-centos8', 'x86_64_v4-centos8', 'skylake-centos8', 'cannonlake-centos7', 'skylake_avx512-centos7', 'x86_64_v4-centos7', 'skylake-centos7', 'cannonlake-slc6', 'skylake_avx512-slc6', 'x86_64_v4-slc6', 'skylake-slc6']
+    ['cannonlake-any', 'skylake_avx512-any', 'x86_64_v4-any', 'skylake-any', 'cannonlake-centos7', 'skylake_avx512-centos7', 'x86_64_v4-centos7', 'skylake-centos7', 'cannonlake-slc6', 'skylake_avx512-slc6', 'x86_64_v4-slc6', 'skylake-slc6']
     >>> compatible_platforms('unkown-slc6')
     []
     """
